@@ -1,9 +1,11 @@
 from pygenomeviz.genbank import Genbank
 from pygenomeviz.genomeviz import GenomeViz
+from pygenomeviz.utils import load_dataset
 
-__version__ = "0.0.6"
+__version__ = "0.0.7"
 
 __all__ = [
     "GenomeViz",
     "Genbank",
+    "load_dataset",
 ]
